@@ -17,12 +17,12 @@ import copy
 from http import client as http_client
 import io
 import json
-import mock
+from unittest import mock
+import zipfile
 
 from sushy import exceptions
 from sushy.resources import base as resource_base
 from sushy.tests.unit import base
-import zipfile
 
 
 BASE_RESOURCE_JSON = {
@@ -40,7 +40,21 @@ BASE_RESOURCE_JSON = {
             "@odata.type": "http://AnotherStandardsBody/schemas.v1_0_1#styleInfoExt",  # noqa
             "Style": "Executive"
         }
+    },
+    "Links": {
+        "Oem": {
+            "Contoso": {
+                "@odata.type": "http://contoso.com/schemas/extensions.v1_2_1#contoso.AnvilTypes1",  # noqa
+                "slogan": "Contoso never fail",
+                "disclaimer": "* Most of the time"
+            },
+            "EID_420_ASB_345": {
+                "@odata.type": "http://AnotherStandardsBody/schemas.v1_0_1#styleInfoExt",  # noqa
+                "Style": "Executive"
+            }
+        }
     }
+
 }
 
 
@@ -139,8 +153,10 @@ class ResourceBaseTestCase(base.TestCase):
         self.assertIsNot(resource_a._reader, resource_b._reader)
 
     def test__parse_attributes(self):
-        for oem_vendor in self.base_resource2.oem_vendors:
-            self.assertTrue(oem_vendor in ('Contoso', 'EID_412_ASB_123'))
+        expected_oem_vendors = ['Contoso', 'EID_412_ASB_123',
+                                'EID_420_ASB_345']
+        actual_oem_vendors = sorted(self.base_resource2.oem_vendors)
+        self.assertEqual(expected_oem_vendors, actual_oem_vendors)
         self.assertEqual('base_resource2', self.base_resource2.resource_name)
 
     def test_refresh_local(self):
@@ -167,7 +183,7 @@ class TestResource(resource_base.ResourceBase):
     """A concrete Test Resource to test against"""
 
     def __init__(self, connector, identity, redfish_version=None,
-                 registries=None):
+                 registries=None, root=None):
         """Ctor of TestResource
 
         :param connector: A Connector instance
@@ -178,7 +194,7 @@ class TestResource(resource_base.ResourceBase):
             used in any resource that needs registries to parse messages.
         """
         super(TestResource, self).__init__(connector, 'Fakes/%s' % identity,
-                                           redfish_version, registries)
+                                           redfish_version, registries, root)
         self.identity = identity
 
     def _parse_attributes(self, json_doc):
@@ -192,7 +208,8 @@ class TestResourceCollection(resource_base.ResourceCollectionBase):
     def _resource_type(self):
         return TestResource
 
-    def __init__(self, connector, redfish_version=None, registries=None):
+    def __init__(self, connector, redfish_version=None, registries=None,
+                 root=None):
         """Ctor of TestResourceCollection
 
         :param connector: A Connector instance
@@ -202,7 +219,7 @@ class TestResourceCollection(resource_base.ResourceCollectionBase):
             used in any resource that needs registries to parse messages.
         """
         super(TestResourceCollection, self).__init__(
-            connector, 'Fakes', redfish_version, registries)
+            connector, 'Fakes', redfish_version, registries, root)
 
 
 class ResourceCollectionBaseTestCase(base.TestCase):
@@ -247,7 +264,7 @@ class ResourceCollectionBaseTestCase(base.TestCase):
         self.assertIsInstance(result, list)
         for val in result:
             self.assertIsInstance(val, TestResource)
-            self.assertTrue(val.identity in member_ids)
+            self.assertIn(val.identity, member_ids)
             self.assertEqual('1.0.x', val.redfish_version)
             self.assertFalse(val._is_stale)
 
